@@ -2,7 +2,7 @@
 #
 # Exercise the opsramp module as an illustration of how to use it.
 #
-# (c) Copyright 2019 Hewlett Packard Enterprise Development LP
+# (c) Copyright 2019-2020 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -25,7 +25,7 @@ import opsramp.rba
 import opsramp.msp
 
 
-CATEGORY_NAME = 'Testing 123'
+CATEGORY_NAME = 'python-opsramp test category'
 
 
 def main():
@@ -49,6 +49,26 @@ def main():
     # Focus on a specific tenant.
     tenant = ormp.tenant(TENANT_ID)
 
+    if tenant.is_client():
+        print('List the First Response Policies on tenant', TENANT_ID)
+        group = tenant.first_response()
+        found = group.search()
+        print(found['totalResults'], 'first response policies')
+        print(yaml.dump(found['results'], default_flow_style=False))
+
+    if tenant.is_client():
+        print('List the Service Maps on tenant', TENANT_ID)
+        group = tenant.service_maps()
+        found = group.get(minimal=True)
+        print(len(found), 'service maps')
+        print(yaml.dump(found, default_flow_style=False))
+
+    print('List the RBAC permission sets on tenant', TENANT_ID)
+    group = tenant.permission_sets()
+    found = group.search()
+    print(found['totalResults'], 'permission_sets')
+    print(yaml.dump(found['results'], default_flow_style=False))
+
     print('List the RBAC roles on tenant', TENANT_ID)
     group = tenant.roles()
     found = group.search()
@@ -101,6 +121,7 @@ def main():
         agent_script = tenant.get_agent_script()
         print('length', len(agent_script))
         print(agent_script.split('\n')[0])
+        print('')
     else:
         print('List the clients of tenant', TENANT_ID)
         group = tenant.clients()
@@ -122,6 +143,15 @@ def main():
         # resp = group.create(cdef)
         # print(resp)
 
+    print('List the Resources on tenant', TENANT_ID)
+    if tenant.is_client():
+        group = tenant.resources()
+        found = group.minimal()
+        print(found['totalResults'], 'resources')
+        print(yaml.dump(found['results']))
+    else:
+        print('<clients only>')
+
     print('List the monitoring templates on tenant', TENANT_ID)
     monitoring = tenant.monitoring()
     templates = monitoring.templates()
@@ -143,40 +173,43 @@ def main():
             cid = c['id']
             break
     else:
-        resp = group.create(CATEGORY_NAME)
-        cid = resp['id']
+        # resp = group.create(CATEGORY_NAME)
+        # cid = resp['id']
+        print('Category {} not found'.format(CATEGORY_NAME))
+        cid = None
 
-    print('Scripts in category', cid)
-    cobj = group.category(cid)
-    slist = cobj.get()
-    print(len(slist), 'scripts')
-    for s in slist:
-        print('...', s['id'], s['name'])
-        direct = cobj.get(s['id'])
-        assert s == direct
+    if cid:
+        print('Scripts in category', cid)
+        cobj = group.category(cid)
+        slist = cobj.get()
+        print(len(slist), 'scripts')
+        for s in slist:
+            print('...', s['id'], s['name'])
+            direct = cobj.get(s['id'])
+            assert s == direct
 
-    # Create a new RBA script in this category, with one parameter. You can
-    # see from the "payload" that this gets passed to the script as $1
-    p1 = cobj.mkParameter(
-        name='venue',
-        description='Where am I today?',
-        datatype='STRING'
-    )
-    print('Parameter definition struct')
-    print(yaml.dump(p1))
-    s1 = cobj.mkScript(
-        name='Hello <venue>',
-        description='Stereotypical rock star intro',
-        platforms=['LINUX'],
-        execution_type='COMMAND',
-        payload='echo "hello $1"',
-        parameters=[p1]
-    )
-    print('Script definition struct')
-    print(yaml.dump(s1))
-    # uncomment these lines to actually create the script.
-    # resp = cobj.create(s1)
-    # print(resp)
+        # Create a new RBA script in this category with one parameter. You can
+        # see from the "payload" that this gets passed to the script as $1
+        p1 = cobj.mkParameter(
+            name='venue',
+            description='Where am I today?',
+            datatype='STRING'
+        )
+        print('Parameter definition struct')
+        print(yaml.dump(p1))
+        s1 = cobj.mkScript(
+            name='Hello <venue>',
+            description='Stereotypical rock star intro',
+            platforms=['LINUX'],
+            execution_type='COMMAND',
+            payload='echo "hello $1"',
+            parameters=[p1]
+        )
+        print('Script definition struct')
+        print(yaml.dump(s1))
+        # uncomment these lines to actually create the script.
+        # resp = cobj.create(s1)
+        # print(resp)
 
     print('Management policies on tenant', TENANT_ID)
     group = tenant.policies()
