@@ -57,8 +57,6 @@ class ApiObjectTest(unittest.TestCase):
             self.fake_auth.copy()
         )
         assert 'ApiObject' in str(self.ao)
-        self.awrapper = opsramp.base.ApiWrapper(self.ao, 'whatevs')
-        assert 'ApiWrapper' in str(self.awrapper)
 
     def test_shared_session(self):
         '''All clones should share the requests session'''
@@ -66,18 +64,46 @@ class ApiObjectTest(unittest.TestCase):
         assert ao2.session is self.ao.session
 
     def test_compute_url(self):
+        # some value, doesn't really matter.
         suffix = 'unit/test/value'
-        expected = self.ao.compute_url() + '/' + suffix
+        expected = self.ao.baseurl + '/' + suffix
         assert self.ao.compute_url(suffix) == expected
+        # empty string and None should both return the root path.
+        rootdir = self.ao.baseurl
+        assert self.ao.compute_url() == rootdir
+        assert self.ao.compute_url('/') == rootdir
+        assert self.ao.compute_url('') == rootdir
+        assert self.ao.compute_url(None) == rootdir
 
     # We're not testing an exhaustive set of suffix patterns here because
     # that is already being done by the PathTracker unit tests.
     def test_cd(self):
+        # some value, doesn't really matter.
         suffix = 'unit/test/cd'
         expected = self.ao.compute_url() + '/' + suffix
         actual = self.ao.cd(suffix)
         assert actual == expected
         assert self.ao.compute_url() == expected
+        # check the root path works.
+        rootdir = self.ao.baseurl
+        self.ao.cd('/random/place1')
+        assert self.ao.compute_url() != rootdir
+        assert self.ao.cd('/') == rootdir
+        assert self.ao.compute_url() == rootdir
+        # no args should default to the root path.
+        self.ao.cd('/random/place0')
+        assert self.ao.compute_url() != rootdir
+        assert self.ao.cd() == rootdir
+        assert self.ao.compute_url() == rootdir
+        # empty string should default to the root path.
+        self.ao.cd('/random/place2')
+        assert self.ao.compute_url() != rootdir
+        assert self.ao.cd('') == rootdir
+        assert self.ao.compute_url() == rootdir
+        # None should default to the root path.
+        self.ao.cd('/random/place3')
+        assert self.ao.cd(None) == rootdir
+        assert self.ao.compute_url() == rootdir
 
     # We're not testing an exhaustive set of suffix patterns here because
     # that is already being done by the PathTracker unit tests.
@@ -306,20 +332,3 @@ class ApiObjectTest(unittest.TestCase):
             m.patch(url, text=expected)
             actual = self.ao.patch()
             assert actual == expected
-
-    # We're not testing an exhaustive set of suffix patterns here because
-    # that is already being done by the ApiObject unit tests. Just
-    # get() and get(something) is enough.
-    def test_wrapped_get(self):
-        with requests_mock.Mocker() as m:
-            url = self.awrapper.api.compute_url()
-            expected = 'unit test wrapped get result'
-            m.get(url, text=expected, complete_qs=True)
-            actual = self.awrapper.get()
-            assert actual == expected
-        with requests_mock.Mocker() as m:
-            suffix = 'some/where/random'
-            url = self.awrapper.api.compute_url(suffix)
-            m.get(url, text=expected, complete_qs=True)
-            actual = self.awrapper.get(suffix)
-            assert actual == expected
